/*
 * Description
 *         HBAAPITEST.C - Sample program which uses the common library API for
 *                        HBA requests.
 *
 * Author
 *         Benjamin F. Kuo, Troika Networks, Inc. (benk@troikanetworks.com)
 *
 * Copyright (c) 2000 Troika Networks, Inc. All Rights Reserved.
 * 
 * Troika Networks, Inc., hereby grants a non-exclusive license under Troika Networks'
 * copyright to copy, modify and distribute this software for any purpose
 * and without fee, provided that the above copyright notice and the
 * following paragraphs appear on all copies.
 * 
 * Troika Networks, Inc.. makes no representation that this source code 
 * is correct or is an accurate representation of any standard.
 * 
 * IN NO EVENT SHALL TROIKA NETWORKS HAVE ANY LIABILITY FOR ANY DIRECT, INDIRECT, OR
 * SPECULATIVE DAMAGES, (INCLUDING WITHOUT LIMITING THE FORGOING,
 * CONSEQUENTIAL, INCIDENTAL AND SPECIAL DAMAGES) INCLUDING, BUT NOT 
 * LIMITED TO INFRINGEMENT, LOSS OF USE, BUSINESS INTERRUPTIONS, AND LOSS 
 * OF PROFITS, IRRESPECTIVE OF WHETHER TROIKA NETWORKS HAS ADVANCE NOTICE OF THE 
 * POSSIBILITY OF ANY SUCH DAMAGES.
 * 
 * TROIKA NETWORKS INC. SPECIFICALLY DISCLAIMS ANY WARRANTIES INCLUDING, BUT 
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR 
 * A PARTICULAR PURPOSE AND NON-INFRINGEMENT.  THE SOFTWARE PROVIDED 
 * HEREUNDER IS ON AN "AS IS" BASIS AND TROIKA NETWORKS INC HAS NO 
 * OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS OR 
 * MODIFICATIONS.
 * 
 *************************************************************************** 
 */



#include <stdio.h>
#ifndef WIN32
#include <dlfcn.h> /* Dynamic library support for Solaris */
#endif
#include "hbaapi.h"

int main(int argc, char* argv[])
{
	HBA_STATUS status;
	int numberofadapters;
	
	char adaptername[256];
	HBA_HANDLE adapterhandle;
	HBA_ADAPTERATTRIBUTES adapterattributes;
	int i;

	/* HBA_LoadLibrary must be called before any other calls */
	HBA_LoadLibrary();
	numberofadapters = HBA_GetNumberOfAdapters();
	printf("There are %d adapters in this system.\r\n", numberofadapters);
	for (i=0; i<numberofadapters; i++) {

		/* Get the name of the adapter */
		status = HBA_GetAdapterName(i, (char *)&adaptername);
		printf("Adapter %d is named %s\r\n", i, adaptername);
		if (status == HBA_STATUS_OK) {
				/* Open the adapter */
				adapterhandle = HBA_OpenAdapter(adaptername);
				/* Get the adapter attributes and print */
				status = HBA_GetAdapterAttributes(adapterhandle, &adapterattributes);
				if (status == HBA_STATUS_OK) {
						printf("Manufacturer:      %s\r\n",adapterattributes.Manufacturer);
						printf("Model:             %s\r\n",adapterattributes.Model);
						printf("Description:       %s\r\n",adapterattributes.ModelDescription);
						printf("NodeSymbolicName:  %s\r\n",adapterattributes.NodeSymbolicName);
						printf("NumberOfPorts:     %d\r\n",adapterattributes.NumberOfPorts);
				}
				/* Close the adapter */
				HBA_CloseAdapter(adapterhandle);
		}

	} /* for adapters */
	/* HBA_FreeLibrary must be called last after all functions are complete */
	HBA_FreeLibrary();
	return 0;
}
